; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------


[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.

command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.

command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
[command]
name = "Mirage Buster"
command = ~D,DF,F,D,DF,F,c+z
time = 20

[command]
name = "Mirage Combo Kick Lv. 1"
command = ~D,DF,F,D,DF,F,x
time = 20

[command]
name = "Mirage Combo Kick Lv. 2"
command = ~D,DF,F,D,DF,F,y
time = 20

[command]
name = "Mirage Combo Kick Lv. 3"
command = ~D,DF,F,D,DF,F,z
time = 20

[command]
name = "Spin Side Shoot Lv. 1"
command = ~D,DF,F,D,DF,F,a
time = 20

[command]
name = "Spin Side Shoot Lv. 2"
command = ~D,DF,F,D,DF,F,b
time = 20

[command]
name = "Spin Side Shoot Lv. 3"
command = ~D,DF,F,D,DF,F,c
time = 20

[command]
name = "Fairy Gift Lv. 1"
command = ~D,DB,B,D,DB,B,x
time = 20

[command]
name = "Fairy Gift Lv. 2"
command = ~D,DB,B,D,DB,B,y
time = 20

[command]
name = "Fairy Gift Lv. 3"
command = ~D,DB,B,D,DB,B,z
time = 20
;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_a"
command = ~F, D, DF, a

[Command]
name = "upper_b"
command = ~F, D, DF, b

[Command]
name = "upper_c"
command = ~F, D, DF, c

[Command]
name = "upper_a"
command = ~F, D, DF, ~a

[Command]
name = "upper_b"
command = ~F, D, DF, ~b

[Command]
name = "upper_c"
command = ~F, D, DF, ~c

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "upper_x"
command = ~F, D, DF, ~x

[Command]
name = "upper_y"
command = ~F, D, DF, ~y

[Command]
name = "upper_z"
command = ~F, D, DF, ~z

[Command]
name = "RDP_a"
command = ~B, D, DB, a

[Command]
name = "RDP_a"
command = ~B, D, DB, ~a

[Command]
name = "RDP_b"
command = ~B, D, DB, b

[Command]
name = "RDP_b"
command = ~B, D, DB, ~b

[Command]
name = "RDP_c"
command = ~B, D, DB, c

[Command]
name = "RDP_c"
command = ~B, D, DB, ~c

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_a"
command = ~D, DF, F, ~a

[Command]
name = "QCF_b"
command = ~D, DF, F, ~b

[Command]
name = "QCF_c"
command = ~D, DF, F, ~c

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_a"
command = ~D, DB, B, ~a

[Command]
name = "QCB_b"
command = ~D, DB, B, ~b

[Command]
name = "QCB_c"
command = ~D, DB, B, ~c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "dodge"
command = x+a
time = 1

[Command]
name = "y+b"
command = y+b
time = 1

[Command]
name = "charge"
command = z+c
time = 1

[Command]
name = "a+b";Required (do not remove)
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdz";Required (do not remove)
command = /$z
time = 1

[Command]
name = "holdc";Required (do not remove)
command = /$c
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
[State -1, Mirage Buster]
type = ChangeState
value = 3080
triggerall = command = "Mirage Buster"
triggerall = statetype = S
triggerall = power = 3000
trigger1 = ctrl = 1
;--------------------------------------------------------------------------
[State -1, Fairy Gift Lv. 3]
type = ChangeState
value = 3073
triggerall = command = "Fairy Gift Lv. 3"
triggerall = statetype = s
triggerall = power = 3000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Fairy Gift Lv. 2]
type = ChangeState
value = 3072
triggerall = command = "Fairy Gift Lv. 2"
triggerall = statetype = s
triggerall = power >= 2000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Fairy Gift Lv. 1]
type = ChangeState
value = 3070
triggerall = command = "Fairy Gift Lv. 1"
triggerall = statetype = s
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Mirage Combo Kick Lv. 3]
type = ChangeState
value = 3002
triggerall = command = "Mirage Combo Kick Lv. 3"
triggerall = statetype = s
triggerall = power = 3000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Mirage Combo Kick Lv. 2]
type = ChangeState
value = 3001
triggerall = command = "Mirage Combo Kick Lv. 2"
triggerall = statetype = s
triggerall = power >= 2000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Mirage Combo Kick Lv. 1]
type = ChangeState
value = 3000
triggerall = command = "Mirage Combo Kick Lv. 1"
triggerall = statetype = s
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Spin Side Shoot Lv. 3]
type = ChangeState
value = 3054
triggerall = command = "Spin Side Shoot Lv. 3"
triggerall = statetype = s
triggerall = power = 3000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Spin Side Shoot Lv. 2]
type = ChangeState
value = 3052
triggerall = command = "Spin Side Shoot Lv. 2"
triggerall = statetype = s
triggerall = power >= 2000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Spin Side Shoot Lv. 1]
type = ChangeState
value = 3050
triggerall = command = "Spin Side Shoot Lv. 1"
triggerall = statetype = s
triggerall = power >= 1000
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;===========================================================================
[State -1, Weak Lightning Knee]
type = ChangeState
value = 1100
triggerall = command = "upper_a"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Medium Lightning Knee]
type = ChangeState
value = 1105
triggerall = command = "upper_b"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Strong Lightning Knee]
type = ChangeState
value = 1110
triggerall = command = "upper_c"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Weak Shoot Upper]
type = ChangeState
value = 1000
triggerall = command = "upper_x"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Medium Shoot Upper]
type = ChangeState
value = 1005
triggerall = command = "upper_y"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Strong Shoot Upper]
type = ChangeState
value = 1010
triggerall = command = "upper_z"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Weak Flip Kick (G)]
type = ChangeState
value = 1135
triggerall = command = "RDP_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Medium Flip Kick (G)]
type = ChangeState
value = 1145
triggerall = command = "RDP_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Strong Flip Kick (G)]
type = ChangeState
value = 1155
triggerall = command = "RDP_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Weak Sliding Arrow]
type = ChangeState
value = 1050
triggerall = command = "QCF_a"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Medium Sliding Arrow]
type = ChangeState
value = 1055
triggerall = command = "QCF_b"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
[State -1, Strong Sliding Arrow]
type = ChangeState
value = 1060
triggerall = command = "QCF_c"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Shoot Kick]
type = ChangeState
value = 1120
triggerall = stateno != [1120,1127]
triggerall = command = "QCB_a" || command = "QCB_b"|| command = "QCB_c"
trigger1 = statetype = s
trigger1 = ctrl = 1
trigger2 = stateno = [200,250]
trigger2 = time > 10
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Weak Flip Kick]
type = ChangeState
value = 1130
triggerall = command = "QCB_a"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [600,650]
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Medium Flip Kick]
type = ChangeState
value = 1140
triggerall = command = "QCB_b"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [600,650]
trigger2 = MoveContact
;----------------------------------------------------------------------------
[State -1, Strong Flip Kick]
type = ChangeState
value = 1150
triggerall = command = "QCB_c"
triggerall = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = [600,650]
trigger2 = MoveContact
;===========================================================================
[State -1, Roll Backwards]
type = ChangeState
value = 903
triggerall = command = "holdback"
triggerall = command = "dodge"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, Roll Forward]
type = ChangeState
value = 902
triggerall = command = "holdfwd"
triggerall = command = "dodge"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, Dodge]
type = ChangeState
value = 901
triggerall = command = "dodge"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, Charge Up]
type = ChangeState
value = 900
triggerall = power < 3000
trigger1 = (command = "holdz")
trigger1 = (command = "holdc")
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = stateno = !11
;---------------------------------------------------------------------------
[State -1, Run Forward]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
[State -1, Punch Throw]
type = ChangeState
value = 800
triggerall = command = "recovery"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
[State -1, Kick Throw]
type = ChangeState
value = 830
triggerall = command = "a+b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;===========================================================================
[State -1, Trick Kick]
type = ChangeState
value = 260
triggerall = command = "holdfwd"
triggerall = command = "y+b"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
;Tegatana
[State -1, Tegatana]
type = ChangeState
value = 215
triggerall = command = "holdfwd"
triggerall = command = "y"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = [200,220]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 10
;---------------------------------------------------------------------------
; Step Side Kick
[State -1, Step Side Kick]
type = ChangeState
value = 245
triggerall = command = "holdfwd"
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = stateno = 230
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = stateno = [230,240]
trigger2 = time > 10
trigger2 = MoveContact
;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400 && time > 10
;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 430 && time > 10
;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
